Index: asterisk/apps/app_voicemail.c
===================================================================
RCS file: /usr/cvsroot/asterisk/apps/app_voicemail.c,v
retrieving revision 1.154
diff -u -r1.154 app_voicemail.c
--- asterisk/apps/app_voicemail.c	2 Oct 2004 14:46:26 -0000	1.154
+++ asterisk/apps/app_voicemail.c	2 Oct 2004 16:09:33 -0000
@@ -150,6 +150,8 @@
 	int envelope;
 	int forcename;
 	int forcegreetings;
+	int sayduration;
+	int saydurationm;
 	struct ast_vm_user *next;
 };
 
@@ -265,6 +267,8 @@
 static int saycidinfo;
 static int svmailinfo;
 static int hearenv;
+static int saydurationinfo;
+static int saydurationminfo;
 static int skipaftercmd;
 static int forcenm;
 static int forcegrt;
@@ -305,6 +309,10 @@
 		vmu->svmail = 1; 
 	if (hearenv)
 		vmu->envelope = 1;
+	if (saydurationinfo)
+		vmu->sayduration = 1;
+	if (saydurationminfo>0)
+		vmu->saydurationm = saydurationminfo;
 	if (forcenm)
 		vmu->forcename = 1;
 	if (forcegrt)
@@ -323,6 +331,7 @@
 	char *stringp = ast_strdupa(options);
 	char *s;
 	char *var, *value;
+	int x;
 	
 	while ((s = strsep(&stringp, "|"))) {
 		value = s;
@@ -365,6 +374,17 @@
 					vmu->envelope = 1;
 				else
 					vmu->envelope = 0;
+			} else if (!strcasecmp(var, "sayduration")){
+				if(ast_true(value))
+					vmu->sayduration = 1;
+				else
+					vmu->sayduration = 0;
+			} else if (!strcasecmp(var, "saydurationm")){
+				if (sscanf(value, "%d", &x) == 1) {
+                                	vmu->saydurationm = x;
+                        	} else {
+                                	ast_log(LOG_WARNING, "Invalid min duration for say duration\n");
+                        	}
 			} else if (!strcasecmp(var, "forcename")){
 				if (ast_true(value))
 					vmu->forcename = 1;
@@ -2496,7 +2516,7 @@
 		}
 	} else {
 		/* Number unknown */
-		ast_log(LOG_DEBUG, "VM-CID: From an unknown number");
+		ast_log(LOG_DEBUG, "VM-CID: From an unknown number\n");
 		if (!res)
 			/* BB: Say "from an unknown caller" as one phrase - it is already recorded by "the voice" anyhow */
 			res = wait_file2(chan, vms, "vm-unknown-caller");
@@ -2504,10 +2524,33 @@
 	return res;
 }
 
+static int play_message_duration(struct ast_channel *chan, struct vm_state *vms, char *duration, int minduration)
+{
+
+        int res = 0;
+        int durationm;
+        int durations;
+        /* Verify that we have a duration for the message */
+        if((duration == NULL))
+                return res;
+
+        /* Convert from seconds to minutes */
+        durations=atoi(duration);
+        durationm=(durations / 60);
+
+        ast_log(LOG_DEBUG, "VM-Duration: duration is: %d seconds converted to: %d minutes\n", durations, durationm);
+
+        if((!res)&&(durationm>=minduration)) {
+                res = ast_say_number(chan, durationm, AST_DIGIT_ANY, chan->language, (char *) NULL);
+                res = wait_file2(chan, vms, "vm-minutes");
+        }
+        return res;
+}
+
 static int play_message(struct ast_channel *chan, struct ast_vm_user *vmu, struct vm_state *vms)
 {
 	int res = 0;
-	char filename[256],*origtime, *cid, *context;
+	char filename[256],*origtime, *cid, *context, *duration;
 	struct ast_config *msg_cfg;
 
 	vms->starting = 0; 
@@ -2538,6 +2581,7 @@
 		return 0;
 
 	cid = ast_variable_retrieve(msg_cfg, "message", "callerid");
+        duration = ast_variable_retrieve(msg_cfg, "message", "duration");
 
 	context = ast_variable_retrieve(msg_cfg, "message", "context");
 	if (!strncasecmp("macro",context,5)) /* Macro names in contexts are useless for our needs */
@@ -2547,6 +2591,8 @@
 		res = play_message_datetime(chan, vmu, origtime, filename);
 	if ((!res)&&(vmu->saycid))
 		res = play_message_callerid(chan, vms, cid, context, 0);
+        if ((!res)&&(vmu->sayduration))
+                res = play_message_duration(chan, vms, duration, vmu->saydurationm);
 	/* Allow pressing '1' to skip envelope / callerid */
 	if (res == '1')
 		res = 0;
@@ -3990,6 +4036,8 @@
 	char *astreview;
 	char *astskipcmd;
 	char *asthearenv;
+	char *astsaydurationinfo;
+	char *astsaydurationminfo;
 	char *silencestr;
 	char *thresholdstr;
 	char *fmt;
@@ -4178,6 +4226,22 @@
 			asthearenv = "yes";
 		}
 		hearenv = ast_true(asthearenv);	
+
+		saydurationinfo = 0;
+		if (!(astsaydurationinfo = ast_variable_retrieve(cfg, "general", "sayduration"))) {
+			ast_log(LOG_DEBUG,"Duration info before msg enabled globally\n");
+			astsaydurationinfo = "yes";
+		}
+		saydurationinfo = ast_true(astsaydurationinfo);	
+
+		saydurationminfo = 2;
+		if ((astsaydurationminfo = ast_variable_retrieve(cfg, "general", "saydurationm"))) {
+			if (sscanf(astsaydurationminfo, "%d", &x) == 1) {
+				saydurationminfo = x;
+			} else {
+				ast_log(LOG_WARNING, "Invalid min duration for say duration\n");
+			}
+		}
 
 		skipaftercmd = 0;
 		if (!(astskipcmd = ast_variable_retrieve(cfg, "general", "nextaftercmd"))) {
Index: asterisk/configs/voicemail.conf.sample
===================================================================
RCS file: /usr/cvsroot/asterisk/configs/voicemail.conf.sample,v
retrieving revision 1.41
diff -u -r1.41 voicemail.conf.sample
--- asterisk/configs/voicemail.conf.sample	2 Oct 2004 03:01:20 -0000	1.41
+++ asterisk/configs/voicemail.conf.sample	2 Oct 2004 16:09:33 -0000
@@ -106,6 +106,10 @@
 ; attach=yes 		; Attach the voicemail to the notification email *NOT* the pager email
 ; saycid=yes 		; Say the caller id information before the message. If not described, 
 			;     or set to no, it will be in the envelope
+; cidinternalcontexts=intern	; Internal Context for Name Playback instead of extension digits when saying caller id.
+; sayduration=no 	; Turn on/off the duration information before the message. [ON by default]
+; saydurationm=2        ; Specify the minimum duration to say. Default is 2 minutes
+
 ; dialout=fromvm 	; Context to dial out from [option 4 from the advanced menu]
 			;     if not listed, dialing out will not be permitted
 sendvoicemail=yes	; Context to Send voicemail from [option 5 from the advanced menu]
@@ -138,7 +142,7 @@
 ;4200 => 9855,Mark Spencer,markster@linux-support.net,mypager@digium.com,attach=no|serveremail=myaddy@digium.com|tz=central
 ;4300 => 3456,Ben Rigas,ben@american-computer.net
 ;4310 => -5432,Sales,sales@marko.net
-;4069 => 6522,Matt Brooks,matt@marko.net,,|tz=central|attach=yes|saycid=yes|dialout=fromvm|callback=fromvm|review=yes|operator=yes|envelope=yes
+;4069 => 6522,Matt Brooks,matt@marko.net,,|tz=central|attach=yes|saycid=yes|dialout=fromvm|callback=fromvm|review=yes|operator=yes|envelope=yes|sayduration=yes|saydurationm=1
 ;4073 => 1099,Bianca Paige,bianca@biancapaige.com,,delete=1
 ;4110 => 3443,Rob Flynn,rflynn@blueridge.net
 ;4321 => 4321,Russell Bryant,russelb@clemson.edu,,|tz=central|attach=no|saycid=yes|dialout=fromvm|callback=fromvm|review=yes|operator=yes|envelope=yes|forcename=yes|forcegreetings=yes
